@@ -7,6 +7,7 @@ from typing import TYPE_CHECKING
 from . import auto_empty, station_action, station_state
 from .advanced_mode import GetAdvancedMode, SetAdvancedMode
 from .battery import GetBattery
+from .border_spin import GetBorderSpin, SetBorderSpin
 from .border_switch import GetBorderSwitch, SetBorderSwitch
 from .carpet import GetCarpetAutoFanBoost, SetCarpetAutoFanBoost
 from .charge import Charge
@@ -27,6 +28,7 @@ from .life_span import GetLifeSpan, ResetLifeSpan
 from .map import (
     GetCachedMapInfo,
     GetMajorMap,
+    GetMapInfoV2,
     GetMapSet,
     GetMapSetV2,
     GetMapSubSet,
@@ -34,6 +36,7 @@ from .map import (
     GetMinorMap,
     SetMajorMap,
 )
+from .mop_auto_wash_frequency import GetMopAutoWashFrequency, SetMopAutoWashFrequency
 from .moveup_warning import GetMoveUpWarning, SetMoveUpWarning
 from .multimap_state import GetMultimapState, SetMultimapState
 from .network import GetNetInfo, GetNetInfoLegacy
@@ -63,6 +66,7 @@ __all__ = [
     "ClearMap",
     "GetAdvancedMode",
     "GetBattery",
+    "GetBorderSpin",
     "GetBorderSwitch",
     "GetCachedMapInfo",
     "GetCarpetAutoFanBoost",
@@ -81,11 +85,13 @@ __all__ = [
     "GetFanSpeed",
     "GetLifeSpan",
     "GetMajorMap",
+    "GetMapInfoV2",
     "GetMapSet",
     "GetMapSetV2",
     "GetMapSubSet",
     "GetMapTrace",
     "GetMinorMap",
+    "GetMopAutoWashFrequency",
     "GetMoveUpWarning",
     "GetMultimapState",
     "GetNetInfo",
@@ -104,6 +110,7 @@ __all__ = [
     "PlaySound",
     "ResetLifeSpan",
     "SetAdvancedMode",
+    "SetBorderSpin",
     "SetBorderSwitch",
     "SetCarpetAutoFanBoost",
     "SetChildLock",
@@ -115,6 +122,7 @@ __all__ = [
     "SetEfficiencyMode",
     "SetFanSpeed",
     "SetMajorMap",
+    "SetMopAutoWashFrequency",
     "SetMoveUpWarning",
     "SetMultimapState",
     "SetOta",
@@ -137,6 +145,9 @@ _COMMANDS: list[type[JsonCommand]] = [
     auto_empty.GetAutoEmpty,
     auto_empty.SetAutoEmpty,
 
+    GetBorderSpin,
+    SetBorderSpin,
+
     GetBorderSwitch,
     SetBorderSwitch,
 
@@ -188,6 +199,7 @@ _COMMANDS: list[type[JsonCommand]] = [
 
     GetCachedMapInfo,
     GetMajorMap,
+    GetMapInfoV2,
     GetMapSet,
     GetMapSetV2,
     GetMapSubSet,
@@ -195,6 +207,9 @@ _COMMANDS: list[type[JsonCommand]] = [
     GetMinorMap,
     SetMajorMap,
 
+    GetMopAutoWashFrequency,
+    SetMopAutoWashFrequency,
+
     GetMoveUpWarning,
     SetMoveUpWarning,
 
