@@ -8,15 +8,17 @@ from typing import TYPE_CHECKING, Any
 
 from deebot_client.util.enum import StrEnumWithXml
 
-from . import auto_empty, station, water_info
+from . import auto_empty, mop_auto_wash_frequency, station, water_info
 from .auto_empty import AutoEmptyEvent
 from .base import Event
 from .efficiency_mode import EfficiencyMode, EfficiencyModeEvent
 from .fan_speed import FanSpeedEvent, FanSpeedLevel
 from .map import (
     CachedMapInfoEvent,
+    GpsPositionEvent,
     MajorMapEvent,
     MapChangedEvent,
+    MapInfoEvent,
     MapSetEvent,
     MapSetType,
     MapSubsetEvent,
@@ -44,8 +46,10 @@ __all__ = [
     "FanSpeedEvent",
     "FanSpeedLevel",
     "FirmwareEvent",
+    "GpsPositionEvent",
     "MajorMapEvent",
     "MapChangedEvent",
+    "MapInfoEvent",
     "MapSetEvent",
     "MapSetType",
     "MapSubsetEvent",
@@ -59,6 +63,7 @@ __all__ = [
     "WorkMode",
     "WorkModeEvent",
     "auto_empty",
+    "mop_auto_wash_frequency",
     "station",
     "water_info",
 ]
@@ -280,6 +285,11 @@ class ChildLockEvent(EnableEvent):
     """Child lock event."""
 
 
+@dataclass(frozen=True)
+class BorderSpinEvent(EnableEvent):
+    """Border spin event."""
+
+
 @dataclass(frozen=True)
 class BorderSwitchEvent(EnableEvent):
     """Border switch event."""
