@@ -11,7 +11,7 @@ from deebot_client.events import Event
 if TYPE_CHECKING:
     from datetime import datetime
 
-    from deebot_client.rs.map import PositionType
+    from deebot_client.rs.map import PositionType, RotationAngle
 
 
 @dataclass(frozen=True)
@@ -31,6 +31,14 @@ class PositionsEvent(Event):
     positions: list[Position]
 
 
+@dataclass(frozen=True)
+class GpsPositionEvent(Event):
+    """GPS position event representation."""
+
+    longitude: float
+    latitude: float
+
+
 @dataclass(frozen=True)
 class MapTraceEvent(Event):
     """Map trace event representation."""
@@ -40,6 +48,14 @@ class MapTraceEvent(Event):
     data: str
 
 
+@dataclass(frozen=True)
+class MapInfoEvent(Event):
+    """Map info event representation."""
+
+    map_id: str
+    info: str
+
+
 @dataclass(frozen=True)
 class MajorMapEvent(Event):
     """Major map event."""
@@ -97,6 +113,7 @@ class Map:
     name: str
     using: bool
     built: bool
+    angle: RotationAngle
 
 
 @dataclass(frozen=True)
