@@ -10,6 +10,7 @@ from deebot_client.events.map import CachedMapInfoEvent, MapChangedEvent
 
 from .events import (
     MajorMapEvent,
+    MapInfoEvent,
     MapSetEvent,
     MapSetType,
     MapSubsetEvent,
@@ -22,7 +23,7 @@ from .events import (
 from .exceptions import MapError
 from .logging_filter import get_logger
 from .models import Room
-from .rs.map import MapData as MapDataRs
+from .rs.map import MapData as MapDataRs, RotationAngle
 from .util import (
     OnChangedDict,
 )
@@ -79,12 +80,14 @@ class Map:
             )
         )
 
+        async def on_map_info(event: MapInfoEvent) -> None:
+            self._map_data.set_map_info(event.info)
+
+        self._unsubscribers.append(event_bus.subscribe(MapInfoEvent, on_map_info))
+
     # ---------------------------- METHODS ----------------------------
 
-    async def _on_first_map_changed_subscription(self) -> Callable[[], None]:
-        """On first MapChanged subscription."""
-        unsubscribers = []
-
+    async def _subscribe_minor_major_map_events(self) -> list[Callable[[], None]]:
         async def on_major_map(event: MajorMapEvent) -> None:
             async with asyncio.TaskGroup() as tg:
                 for idx, value in enumerate(event.values):
@@ -98,17 +101,22 @@ class Map:
                             )
                         )
 
-        unsubscribers.append(self._event_bus.subscribe(MajorMapEvent, on_major_map))
-
         async def on_minor_map(event: MinorMapEvent) -> None:
             self._map_data.update_map_piece(event.index, event.value)
 
-        unsubscribers.append(self._event_bus.subscribe(MinorMapEvent, on_minor_map))
+        return [
+            self._event_bus.subscribe(MajorMapEvent, on_major_map),
+            self._event_bus.subscribe(MinorMapEvent, on_minor_map),
+        ]
 
-        async def on_cached_info(_: CachedMapInfoEvent) -> None:
-            # We need to subscribe to it, otherwise it could happen
-            # that the required MapSet Events are not get
-            pass
+    async def _on_first_map_changed_subscription(self) -> Callable[[], None]:
+        """On first MapChanged subscription."""
+        unsubscribers = await self._subscribe_minor_major_map_events()
+
+        async def on_cached_info(event: CachedMapInfoEvent) -> None:
+            used_map = next((m for m in event.maps if m.using), None)
+            if used_map:
+                self._map_data.set_rotation_angle(used_map.angle)
 
         cached_map_subscribers = self._event_bus.has_subscribers(CachedMapInfoEvent)
         unsubscribers.append(
@@ -144,6 +152,7 @@ class Map:
             raise MapError("Please enable the map first")
 
         # TODO make it nice
+        self._event_bus.request_refresh(CachedMapInfoEvent)
         self._event_bus.request_refresh(PositionsEvent)
         self._event_bus.request_refresh(MapTraceEvent)
         self._event_bus.request_refresh(MajorMapEvent)
@@ -171,6 +180,7 @@ class Map:
         for unsubscribe in self._unsubscribers:
             unsubscribe()
         self._unsubscribers.clear()
+        self._map_data.teardown()
 
 
 class MapData:
@@ -186,6 +196,7 @@ class MapData:
         self._on_change = on_change
         self._map_subsets: OnChangedDict[int, MapSubsetEvent] = OnChangedDict(on_change)
         self._positions: list[Position] = []
+        self._rotation: RotationAngle = RotationAngle.DEG_0
         self._data = MapDataRs()
         self._room_handling = MapRoomHandling(event_bus, on_change)
 
@@ -205,12 +216,12 @@ class MapData:
 
     def add_trace_points(self, value: str) -> None:
         """Add trace points to the map data."""
-        self._data.add_trace_points(value)
+        self._data.trace_points.add(value)
         self._on_change()
 
     def clear_trace_points(self) -> None:
         """Clear trace points."""
-        self._data.clear_trace_points()
+        self._data.trace_points.clear()
         self._on_change()
 
     def update_positions(self, value: list[Position]) -> None:
@@ -220,19 +231,37 @@ class MapData:
 
     def update_map_piece(self, index: int, base64_data: str) -> None:
         """Update map piece."""
-        if self._data.update_map_piece(index, base64_data):
+        if self._data.background_image.update_map_piece(index, base64_data):
             self._on_change()
 
     def map_piece_crc32_indicates_update(self, index: int, crc32: int) -> bool:
         """Return True if update is required."""
-        return self._data.map_piece_crc32_indicates_update(index, crc32)
+        return self._data.background_image.map_piece_crc32_indicates_update(
+            index, crc32
+        )
 
     def generate_svg(self) -> str | None:
         """Generate SVG image."""
         return self._data.generate_svg(
-            list(self._map_subsets.values()), self._positions
+            list(self._map_subsets.values()),
+            self._positions,
+            self._rotation,
         )
 
+    def set_map_info(self, base64_info: str) -> None:
+        """Set compressed map info (parsing happens in Rust)."""
+        self._data.map_info.set(base64_info)
+        self._on_change()
+
+    def set_rotation_angle(self, rotation: RotationAngle) -> None:
+        """Set clockwise rotation angle for SVG image."""
+        self._rotation = rotation
+        self._on_change()
+
+    def teardown(self) -> None:
+        """Teardown map data."""
+        self._room_handling.teardown()
+
 
 class MapRoomHandling:
     """Room handling."""
@@ -265,3 +294,9 @@ class MapRoomHandling:
                     event_bus.notify(RoomsEvent(list(self._rooms.values())))
 
         self._unsubscribers.append(event_bus.subscribe(MapSubsetEvent, on_map_subset))
+
+    def teardown(self) -> None:
+        """Teardown room handling."""
+        for unsubscribe in self._unsubscribers:
+            unsubscribe()
+        self._unsubscribers.clear()
