@@ -4,7 +4,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any
 
-from deebot_client.events import CleanJobStatus, ReportStatsEvent
+from deebot_client.events import CleanJobStatus, ReportStatsEvent, StatsEvent
 from deebot_client.message import HandlingResult, MessageBodyDataDict
 
 if TYPE_CHECKING:
@@ -40,3 +40,22 @@ class ReportStats(MessageBodyDataDict):
         )
         event_bus.notify(stats_event)
         return HandlingResult.success()
+
+
+class OnStats(MessageBodyDataDict):
+    """Get stats command."""
+
+    NAME = "onStats"
+
+    @classmethod
+    def _handle_body_data_dict(
+        cls, event_bus: EventBus, data: dict[str, Any]
+    ) -> HandlingResult:
+        """Handle message->body->data and notify the correct event subscribers.
+
+        :return: A message response
+        """
+        event_bus.notify(
+            StatsEvent(area=data["area"], time=data["time"], type=data.get("type"))
+        )
+        return HandlingResult.success()
